==> bson-2.14.0-sources.jar: org/bson/types/Binary.java <==
/*
 * Copyright (c) 2008-2014 MongoDB, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.bson.types;

import org.bson.BSON;

import java.io.Serializable;
import java.util.Arrays;

/**
 * Generic binary holder.
 */
public class Binary implements Serializable {

    private static final long serialVersionUID = 7902997490338209467L;

    /**
     * Creates a Binary object with the default binary type of 0
     *
     * @param data raw data
     */
    public Binary(byte[] data) {
        this(BSON.B_GENERAL, data);
    }

    /**
     * Creates a Binary with the specified type and data.
     *
     * @param type the binary type
     * @param data the binary data
     */
    public Binary(byte type, byte[] data) {
        _type = type;
        _data = data;
    }

    /**
     * Get the binary sub type as a byte.
     *
     * @return the binary sub type as a byte.
     */
    public byte getType() {
        return _type;
    }

    /**
     * Get a copy of the binary value.
     *
     * @return a copy of the binary value.
     */
    public byte[] getData() {
        return _data;
    }

    /**
     * Get the length of the data.
     *
     * @return the length of the binary array.
     */
    public int length() {
        return _data.length;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof Binary)) {
            return false;
        }

        Binary binary = (Binary) o;

        if (_type != binary._type) {
            return false;
        }
        if (!Arrays.equals(_data, binary._data)) {
            return false;
        }

        return true;
    }

    @Override
    public int hashCode() {
        int result = (int) _type;
        result = 31 * result + (_data != null ? Arrays.hashCode(_data) : 0);
        return result;
    }

    final byte _type;
    final byte[] _data;
}

==> bson-4.7.2-sources.jar: org/bson/types/Binary.java <==
/*
 * Copyright 2008-present MongoDB, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.bson.types;

import org.bson.BsonBinarySubType;

import java.io.Serializable;
import java.util.Arrays;

/**
 * Generic binary holder.
 */
public class Binary implements Serializable {
    private static final long serialVersionUID = 7902997490338209467L;

    /**
     * The binary sub-type.
     */
    private final byte type;

    /**
     * The binary data.
     */
    private final byte[] data;

    /**
     * Creates a Binary object with the default binary type of 0
     *
     * @param data raw data
     */
    public Binary(final byte[] data) {
        this(BsonBinarySubType.BINARY, data);
    }

    /**
     * Creates a Binary with the specified type and data.
     *
     * @param type the binary type
     * @param data the binary data
     */
    public Binary(final BsonBinarySubType type, final byte[] data) {
        this(type.getValue(), data);
    }

    /**
     * Creates a Binary object
     *
     * @param type type of the field as encoded in BSON
     * @param data raw data
     */
    public Binary(final byte type, final byte[] data) {
        this.type = type;
        this.data = data.clone();
    }

    /**
     * Get the binary sub type as a byte.
     *
     * @return the binary sub type as a byte.
     */
    public byte getType() {
        return type;
    }

    /**
     * Get a copy of the binary value.
     *
     * @return a copy of the binary value.
     */
    public byte[] getData() {
        return data.clone();
    }

    /**
     * Get the length of the data.
     *
     * @return the length of the binary array.
     */
    public int length() {
        return data.length;
    }

    @Override
    public boolean equals(final Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }

        Binary binary = (Binary) o;

        if (type != binary.type) {
            return false;
        }
        if (!Arrays.equals(data, binary.data)) {
            return false;
        }

        return true;
    }

    @Override
    public int hashCode() {
        int result = (int) type;
        result = 31 * result + Arrays.hashCode(data);
        return result;
    }
}
